pub struct ExtensionType {
pub extension_urn_reference: u32,
pub type_anchor: u32,
pub name: String,
}Expand description
Describes a Type
Fields
extension_urn_reference: u32references the extension_urn_anchor defined for a specific extension URN.
type_anchor: u32A surrogate key used in the context of a single plan to reference a specific extension type. 0 is a valid anchor/reference, but prefer non-zero values for ergonomics.
name: Stringthe name of the type in the defined extension YAML.