pub struct ExtensionTypeVariation {
pub extension_urn_reference: u32,
pub type_variation_anchor: u32,
pub name: String,
}Fields
extension_urn_reference: u32references the extension_urn_anchor defined for a specific extension URN.
type_variation_anchor: u32A surrogate key used in the context of a single plan to reference a specific type variation. Use non-zero values; 0 is reserved for the system-preferred variation.
name: Stringthe name of the type in the defined extension YAML.